@@ -4,7 +4,9 @@ from archimedes.data.common import get_api_base_url_v2
 from archimedes.utils.api_request import api
 
 
-def list_series_price_areas(series_id: str, *, access_token: str = None):
+def list_series_price_areas(
+    series_id: str, *, access_token: str = None, **kwargs
+) -> pd.DataFrame:
     """
     Retrieve all the price_areas which are available for the specified data series
 
@@ -29,6 +31,7 @@ def list_series_price_areas(series_id: str, *, access_token: str = None):
         f"{base_url}/data/list_series_price_areas",
         access_token=access_token,
         params=query,
+        **kwargs,
     )
     data = pd.DataFrame.from_dict(data)
 
@@ -36,6 +39,7 @@ def list_series_price_areas(series_id: str, *, access_token: str = None):
         f"{base_url}/observation_json/list_series_price_areas",
         access_token=access_token,
         params=query,
+        **kwargs,
     )
     observation_data = pd.DataFrame.from_dict(observation_data)
 
@@ -44,7 +48,7 @@ def list_series_price_areas(series_id: str, *, access_token: str = None):
     return price_area_df
 
 
-def list_ids(sort: bool = False, *, access_token: str = None):
+def list_ids(sort: bool = False, *, access_token: str = None, **kwargs) -> pd.DataFrame:
     """List all the series ids available.
 
     Example:
@@ -66,12 +70,13 @@ def list_ids(sort: bool = False, *, access_token: str = None):
         DataFrame with all available list_ids
     """
     base_url = get_api_base_url_v2()
-    data = api.request(f"{base_url}/data/list_ids", access_token=access_token)
+    data = api.request(f"{base_url}/data/list_ids", access_token=access_token, **kwargs)
     data = pd.DataFrame.from_dict(data)
 
     observation_data = api.request(
         f"{base_url}/observation_json/list_ids",
         access_token=access_token,
+        **kwargs,
     )
     observation_data = pd.DataFrame.from_dict(observation_data)
 
@@ -90,7 +95,7 @@ def list_ids(sort: bool = False, *, access_token: str = None):
     return series_df.copy()
 
 
-def list_prediction_ids(*, access_token: str = None):
+def list_prediction_ids(*, access_token: str = None, **kwargs) -> pd.DataFrame:
     """List all the prediction series ids available.
 
     Example:
@@ -107,6 +112,7 @@ def list_prediction_ids(*, access_token: str = None):
     data = api.request(
         f"{get_api_base_url_v2()}/data/list_prediction_ids",
         access_token=access_token,
+        **kwargs,
     )
 
     return pd.DataFrame.from_dict(data)
